<?php

namespace App\Mobile\Synchronization\Requests;

use App\Domain\Logs\Model\ErrorLog;
use App\Domain\Logs\Service\SaveError;
use Illuminate\Contracts\Validation\Validator;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\ValidationException;

class UploadSyncRouteRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    protected function failedValidation(Validator $validator)
    {
        SaveError::generateLog(ErrorLog::MOVEL_GET_SYNC_ROUTE, json_encode($this->all()), $validator->errors()->toJson());
        parent::failedValidation($validator);
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'mvfs' => 'present|array',
            'mvfs.*.mvf_codigo' => 'integer',
            'mvfs.*.parcelas' => 'present|array',
            'mvfs.*.parcelas.*.par_codigo' => 'integer',
            'mvfs.*.parcelas.*.valor' => 'numeric',
            'mvfs.*.parcelas.*.data_pagamento' => 'string|date_format:Y-m-d H:i:s',
            'mvfs.*.parcelas.*.descricao' => 'present|string',

            //Caso futuramente tenha uma funcionalidade do app criar pagamentos não previstos.
            //Obs: ajustar objeto conforme definir regra funcionamento
            'unexpected_payments' => 'nullable|array',
            'unexpected_payments.*.pes_codigo' => 'nullable|integer',
            'unexpected_payments.*.pes_name' => 'nullable|string',
            'unexpected_payments.*.valor' => 'numeric',
            'unexpected_payments.*.data_pagamento' => 'string|date_format:Y-m-d H:i:s',
        ];
    }
}
